Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code | Sign in
(1258)

Unified Diff: src/internet/test/tcp-rto-test.cc

Issue 299130043: TCP SACK + SACK emulation
Patch Set: Fixed NextSeg Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Please Sign in to add in-line comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/internet/test/tcp-rto-test.h ('k') | src/internet/test/tcp-rx-buffer-test.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/internet/test/tcp-rto-test.cc
diff --git a/src/internet/test/tcp-rto-test.cc b/src/internet/test/tcp-rto-test.cc
index 69363dc58f6442093116a47c86d9fff3a9546462..4561f3647887ba602ebe909ddc86d1e008738ac8 100644
--- a/src/internet/test/tcp-rto-test.cc
+++ b/src/internet/test/tcp-rto-test.cc
@@ -29,7 +29,7 @@ NS_LOG_COMPONENT_DEFINE ("TcpRtoTest");
TcpRtoTest::TcpRtoTest (TypeId &congControl, const std::string &desc)
: TcpGeneralTest (desc),
- m_rtoExpired (false),
+ m_afterRTOExpired (false),
m_segmentReceived (false)
{
m_congControlTypeId = congControl;
@@ -61,17 +61,17 @@ TcpRtoTest::CreateSenderSocket (Ptr<Node> node)
}
void
-TcpRtoTest::RTOExpired (const Ptr<const TcpSocketState> tcb, SocketWho who)
+TcpRtoTest::AfterRTOExpired (const Ptr<const TcpSocketState> tcb, SocketWho who)
{
// In this test, the RTO fires for the first segment (and no more).
// This function is called after the management of the RTO expiration,
// and because of this we must check all the involved variables.
- NS_TEST_ASSERT_MSG_EQ (m_rtoExpired, false,
+ NS_TEST_ASSERT_MSG_EQ (m_afterRTOExpired, false,
"Second RTO expired");
NS_TEST_ASSERT_MSG_EQ (GetCongStateFrom (tcb), TcpSocketState::CA_LOSS,
"Ack state machine not in LOSS state after a loss");
- m_rtoExpired = true;
+ m_afterRTOExpired = true;
}
void
@@ -80,11 +80,11 @@ TcpRtoTest::RcvAck (const Ptr<const TcpSocketState> tcb, const TcpHeader& h,
{
// Called after the first ack is received (the lost segment has been
// successfully retransmitted. We must check on the sender that variables
// are in the same state as they where after RTOExpired if it is the first
// ACK after the loss; in every other case, all must be OPEN and the counter
// set to 0.
- if (m_rtoExpired && who == SENDER)
+ if (m_afterRTOExpired && who == SENDER)
{
NS_TEST_ASSERT_MSG_EQ (GetCongStateFrom (tcb), TcpSocketState::CA_LOSS,
"Ack state machine not in LOSS state after a loss");
@@ -110,7 +110,7 @@ TcpRtoTest::ProcessedAck (const Ptr<const TcpSocketState> tcb, const TcpHeader &
if (who == SENDER)
{
- m_rtoExpired = false;
+ m_afterRTOExpired = false;
m_segmentReceived = true;
}
}
@@ -244,7 +244,7 @@ TcpTimeRtoTest::ErrorClose (SocketWho who)
}
void
-TcpTimeRtoTest::RTOExpired (const Ptr<const TcpSocketState> tcb, SocketWho who)
+TcpTimeRtoTest::AfterRTOExpired (const Ptr<const TcpSocketState> tcb, SocketWho who)
{
NS_TEST_ASSERT_MSG_EQ (who, SENDER, "RTO in Receiver. That's unexpected");
« no previous file with comments | « src/internet/test/tcp-rto-test.h ('k') | src/internet/test/tcp-rx-buffer-test.cc » ('j') | no next file with comments »
@@ -80,11 +80,11 @@ TcpRtoTest::RcvAck (const Ptr<const TcpSocketState> tcb, const TcpHeader& h,
// Called after the first ack is received (the lost segment has been
// successfully retransmitted. We must check on the sender that variables
- // are in the same state as they where after RTOExpired if it is the first
+ // are in the same state as they where after AfterRTOExpired if it is the first
// ACK after the loss; in every other case, all must be OPEN and the counter
// set to 0.

Powered by Google App Engine
RSS Feeds Recent Issues | This issue
This is Rietveld f62528b